Contact and Support
======================


If you have any question about the toolbox or if you want to collaborate in the project, please do not hesitate to
contact us. You can do it through the following email address: inferpy.api@gmail.com


For more technical questions, please use `Github issues <https://github.com/PGM-Lab/InferPy/issues>`_.


